package RogueCurses::Messages::Lubina::lubina;

### 
### Lubina is a Sampling and/or Strategy library
###

sub new {
	my ($class) = @_;

	$self = { probability => -1 };

	$class = ref($class) || $class;
	bless $self, $class;
}

sub work_on_nouns {
	my ($self, @values) = @_; ### @values is a list of lists of words,
				### mostly nouns

}
1;
