package RogueCurses::Messages::Lubina::fam;

### 
### Fuzzy Associative Matrix 
###

sub new {
	my ($class, $m, $n) = @_;

	my $self = $class->SUPER::new;
	$self->{wordmatrix} = RogueCurses::Messages::Lubina::matrixmn->new($m, $n);
	$self->{numbermatrix} = RogueCurses::Messages::Lubina::matrixmn->new($m, $n);
}

sub add_number_row {
	my ($self, @l) = @_;

	$self->{numbermatrix}->add_number_row(@l);	
}

sub add_word_row {
	my ($self, @l) = @_;

	$self->{wordmatrix}->add_number_row(@l);	
}
